==> qtbase-opensource-src_5.0.1+dfsg.orig.tar.xz: qtbase-opensource-src-5.0.1/src/platformsupport/linuxaccessibility/bridge_p.h <==
/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/


#ifndef QSPIACCESSIBLEBRIDGE_H
#define QSPIACCESSIBLEBRIDGE_H

#include <QtDBus/qdbusconnection.h>
#include <qpa/qplatformaccessibility.h>

class DeviceEventControllerAdaptor;

QT_BEGIN_HEADER
QT_BEGIN_NAMESPACE

class DBusConnection;
class QSpiDBusCache;
class AtSpiAdaptor;

class QSpiAccessibleBridge: public QObject, public QPlatformAccessibility
{
    Q_OBJECT
public:
    QSpiAccessibleBridge();

    virtual ~QSpiAccessibleBridge();
    virtual void setRootObject(QObject *obj);

    virtual void notifyAccessibilityUpdate(QAccessibleEvent *event);
    QDBusConnection dBusConnection() const;

private:
    void initializeConstantMappings();

    QSpiDBusCache *cache;
    DeviceEventControllerAdaptor *dec;

    AtSpiAdaptor *dbusAdaptor;

    DBusConnection* dbusConnection;
    bool initialized;
};

QT_END_NAMESPACE
QT_END_HEADER

#endif

==> qtbase-opensource-src_5.0.2+dfsg1.orig.tar.xz: qtbase-opensource-src-5.0.2+dfsg1/src/platformsupport/linuxaccessibility/bridge_p.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/


#ifndef QSPIACCESSIBLEBRIDGE_H
#define QSPIACCESSIBLEBRIDGE_H

#include <QtDBus/qdbusconnection.h>
#include <qpa/qplatformaccessibility.h>

class DeviceEventControllerAdaptor;

QT_BEGIN_HEADER
QT_BEGIN_NAMESPACE

class DBusConnection;
class QSpiDBusCache;
class AtSpiAdaptor;

class QSpiAccessibleBridge: public QObject, public QPlatformAccessibility
{
    Q_OBJECT
public:
    QSpiAccessibleBridge();

    virtual ~QSpiAccessibleBridge();

    virtual void notifyAccessibilityUpdate(QAccessibleEvent *event);
    QDBusConnection dBusConnection() const;

public Q_SLOTS:
    void enabledChanged(bool enabled);

private:
    void initializeConstantMappings();
    void updateStatus();

    QSpiDBusCache *cache;
    DeviceEventControllerAdaptor *dec;
    AtSpiAdaptor *dbusAdaptor;
    DBusConnection* dbusConnection;
    bool m_enabled;
};

QT_END_NAMESPACE
QT_END_HEADER

#endif
